# Regression Head

::: linax.heads.regression.RegressionHeadConfig
    options:
      members:
        - build

---

::: linax.heads.regression.RegressionHead
    options:
      members:
        - __init__
        - __call__
